communication library

A library for collecting communication data, from

  • text messages (sms)
  • phone calls
  • calendar entries

Classes

Calendar
Holds a list of calendar events from the device.
CalendarEvent
A calendar event.
CalendarProbe
A probe collecting calendar entries from the calendar on the phone.
CommunicationSamplingPackage
This is the base class for this communication sampling package.
PhoneCall
Phone call data.
PhoneLog
Holds a phone log, i.e. a list of phone calls made on the device.
PhoneLogProbe
A probe that collects the phone log from this device.
TextMessage
Holds a text messages (SMS).
TextMessageLog
Holds a list of text (SMS) messages from the device.
TextMessageLogProbe
A probe that collects a complete list of all text (SMS) messages from this device. Combines both send and received messages.
TextMessageProbe
The TextMessageProbe listens to SMS messages and collects a TextMessage every time a new SMS message is received.

Functions

backgroundMessageHandler(SmsMessage message) → void
The top-level call-back method for handling in-coming SMS messages when the app is in the background.
calendarAnonymizer(Data data) → Data
A Calendar anonymizer function. Anonymizes each CalendarEvent entry in the calendar using the calendarEventAnonymizer function.
calendarEventAnonymizer(CalendarEvent event) CalendarEvent
A CalendarEvent anonymizer function. Anonymizes:
phoneCallAnonymizer(PhoneCall call) PhoneCall
A PhoneCall anonymizer function. Anonymizes:
phoneLogAnonymizer(Data data) → Data
A PhoneLog anonymizer function. Anonymizes each PhoneCall entry in the log using the phoneCallAnonymizer function.
textMessageAnonymizer(Data data) TextMessage
A TextMessage anonymizer function. Anonymizes:
textMessageLogAnonymizer(Data data) → Data
A TextMessageLog anonymizer function. Anonymizes each TextMessage entry in the log using the textMessageAnonymizer function.