CalendarEvent class
A calendar event.
- Annotations
-
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Constructors
- CalendarEvent([String? eventId, String? calendarId, String? title, String? description, DateTime? start, DateTime? end, bool? allDay, String? location, String? status, String? timeZone, bool isRecurring = false])
- CalendarEvent.fromEvent(Event event)
-
factory
-
CalendarEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allDay ↔ bool?
-
Indicates if this is an all-day event
getter/setter pair
- calendarId ↔ String?
-
The identifier of the calendar that this event is associated with
getter/setter pair
- description ↔ String?
-
The description for this event
getter/setter pair
- end ↔ DateTime?
-
Indicates when the event ends
getter/setter pair
- eventId ↔ String?
-
The unique identifier for this event
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecurring → bool
-
Whether this is a recurring event.
True for recurring events, false for one-time events.
final
- location ↔ String?
-
The location of this event
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start ↔ DateTime?
-
Indicates when the event starts
getter/setter pair
- status → String?
-
Status of the event.
final
- timeZone → String?
-
Timezone identifier for the event (e.g., "America/New_York").
Null for all-day events (floating dates).
final
- title ↔ String?
-
The title of this event
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited